==> moodle_1.3.1.orig.tar.gz: moodle/lang/es/countries.php <==
<?PHP // $Id: countries.php,v 1.5 2003/12/08 06:58:12 moodler Exp $ 
      // countries.php - created with Moodle 1.2 development (2003120700)


$string['AD'] = 'Andorra';
$string['AE'] = 'Emiratos rabes Unidos';
$string['AF'] = 'Afganistn';
$string['AG'] = 'Antigua y Barbuda';
$string['AI'] = 'Anguila';
$string['AL'] = 'Albania';
$string['AM'] = 'Armenia';
$string['AN'] = 'Antillas Holandesas';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antrtida';
$string['AR'] = 'Argentina';
$string['AS'] = 'Samoa Americana';
$string['AT'] = 'Austria';
$string['AU'] = 'Australia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaiyn';
$string['BA'] = 'Bosnia y Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladesh';
$string['BE'] = 'Blgica';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgaria';
$string['BH'] = 'Bahrein';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BN'] = 'Brunei Darussalam';
$string['BO'] = 'Bolivia';
$string['BR'] = 'Brasil';
$string['BS'] = 'Bahamas';
$string['BT'] = 'Butn';
$string['BV'] = 'Islas Bouvet';
$string['BW'] = 'Botswana';
$string['BY'] = 'Bielorrusia';
$string['BZ'] = 'Belice';
$string['CA'] = 'Canad';
$string['CC'] = 'Islas Cocos';
$string['CF'] = 'Repblica Centroafricana';
$string['CG'] = 'Congo';
$string['CH'] = 'Suiza';
$string['CI'] = 'Costa de Marfil';
$string['CK'] = 'Islas Cook';
$string['CL'] = 'Chile';
$string['CM'] = 'Camern';
$string['CN'] = 'China';
$string['CO'] = 'Colombia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Serbia y Montenegro';
$string['CU'] = 'Cuba';
$string['CV'] = 'Cabo Verde';
$string['CX'] = 'Islas de Navidad';
$string['CY'] = 'Chipre';
$string['CZ'] = 'Repblica Checa';
$string['DE'] = 'Alemania';
$string['DJ'] = 'Djibouti';
$string['DK'] = 'Dinamarca';
$string['DM'] = 'Dominica';
$string['DO'] = 'Repblica Dominicana';
$string['DZ'] = 'Argelia';
$string['EC'] = 'Ecuador';
$string['EE'] = 'Estonia';
$string['EG'] = 'Egipto';
$string['EH'] = 'Sahara Occidental';
$string['ER'] = 'Eritrea';
$string['ES'] = 'Espaa';
$string['ET'] = 'Etiopa';
$string['FI'] = 'Finlandia';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Islas Malvinas';
$string['FM'] = 'Micronesia';
$string['FO'] = 'Islas Faroe';
$string['FR'] = 'Francia';
$string['FX'] = 'Francia Metropolitana';
$string['GA'] = 'Gabn';
$string['GB'] = 'Reino Unido';
$string['GD'] = 'Granada';
$string['GE'] = 'Georgia';
$string['GF'] = 'Guyana Francesa';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Groenlandia';
$string['GM'] = 'Gambia';
$string['GN'] = 'Guinea';
$string['GP'] = 'Guadalupe';
$string['GQ'] = 'Guinea Ecuatorial';
$string['GR'] = 'Grecia';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guyana';
$string['HK'] = 'Hong Kong';
$string['HM'] = 'Islas Heard y McDonald';
$string['HN'] = 'Honduras';
$string['HR'] = 'Croacia';
$string['HT'] = 'Hait';
$string['HU'] = 'Hungra';
$string['ID'] = 'Indonesia';
$string['IE'] = 'Irlanda';
$string['IL'] = 'Israel';
$string['IN'] = 'India';
$string['IO'] = 'Territorio Britnico del Ocano ndico';
$string['IQ'] = 'Irak';
$string['IR'] = 'Irn';
$string['IS'] = 'Islandia';
$string['IT'] = 'Italia';
$string['JM'] = 'Jamaica';
$string['JO'] = 'Jordania';
$string['JP'] = 'Japn';
$string['KE'] = 'Kenia';
$string['KG'] = 'Kirguistn';
$string['KH'] = 'Camboya';
$string['KI'] = 'Kiribati';
$string['KM'] = 'Comoras';
$string['KN'] = 'San Cristbal Nevis';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Corea del Norte';
$string['KR'] = 'Corea del Sur';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Islas Caimn';
$string['KZ'] = 'Kazajstn';
$string['LA'] = 'Laos';
$string['LB'] = 'Lbano';
$string['LC'] = 'Santa Luca';
$string['LI'] = 'Liechtenstein';
$string['LK'] = 'Sri Lanka';
$string['LR'] = 'Liberia';
$string['LS'] = 'Lesotho';
$string['LT'] = 'Lituania';
$string['LU'] = 'Luxemburgo';
$string['LV'] = 'Latvia';
$string['LY'] = 'Jamahiriya rabe Libia';
$string['MA'] = 'Marruecos';
$string['MC'] = 'Mnaco';
$string['MD'] = 'Moldovia';
$string['MG'] = 'Madagascar';
$string['MH'] = 'Islas Marshall';
$string['MK'] = 'Macedonia';
$string['ML'] = 'Mali';
$string['MM'] = 'Myanmar';
$string['MN'] = 'Mongolia';
$string['MO'] = 'Macao';
$string['MP'] = 'Islas Marianas del Norte';
$string['MQ'] = 'Martinica';
$string['MR'] = 'Mauritania';
$string['MS'] = 'Montserrat';
$string['MT'] = 'Malta';
$string['MU'] = 'Mauricio';
$string['MV'] = 'Maldivas';
$string['MW'] = 'Malawi';
$string['MX'] = 'Mxico';
$string['MY'] = 'Malasia';
$string['MZ'] = 'Mozambique';
$string['NA'] = 'Namibia';
$string['NC'] = 'Nueva Caledonia';
$string['NE'] = 'Nger';
$string['NF'] = 'Islas Norfolk';
$string['NG'] = 'Nigeria';
$string['NI'] = 'Nicaragua';
$string['NL'] = 'Holanda';
$string['NO'] = 'Noruega';
$string['NP'] = 'Nepal';
$string['NR'] = 'Naur';
$string['NU'] = 'Niue';
$string['NZ'] = 'Nueva Zelandia';
$string['OM'] = 'Omn';
$string['PA'] = 'Panam';
$string['PE'] = 'Per';
$string['PF'] = 'Polinesia Francesa';
$string['PG'] = 'Papa Nueva Guinea';
$string['PH'] = 'Filipinas';
$string['PK'] = 'Pakistn';
$string['PL'] = 'Polonia';
$string['PM'] = 'San Pedro y Miquelon';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Puerto Rico';
$string['PT'] = 'Portugal';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguay';
$string['QA'] = 'Qatar';
$string['RE'] = 'Reunin';
$string['RO'] = 'Rumania';
$string['RU'] = 'Federacin Rusa';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Arabia Saudita';
$string['SB'] = 'Islas Salomn';
$string['SC'] = 'Seychelles';
$string['SD'] = 'Sudn';
$string['SE'] = 'Suecia';
$string['SG'] = 'Singapur';
$string['SH'] = 'Santa Helena';
$string['SI'] = 'Eslovenia';
$string['SJ'] = 'Islas Svalbard y Jan Mayen';
$string['SK'] = 'Eslovaquia';
$string['SL'] = 'Sierra Leona';
$string['SM'] = 'San Marino';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somala';
$string['SR'] = 'Surinam';
$string['ST'] = 'Santo Tom y Prncipe';
$string['SV'] = 'El Salvador';
$string['SY'] = 'Siria';
$string['SZ'] = 'Swazilandia';
$string['TC'] = 'Islas Turcas y Caicos';
$string['TD'] = 'Chad';
$string['TF'] = 'Territorios Franceses del Sur';
$string['TG'] = 'Togo';
$string['TH'] = 'Tailandia';
$string['TJ'] = 'Tayikistn';
$string['TK'] = 'Tokelau';
$string['TM'] = 'Turkmenistn';
$string['TN'] = 'Tnez';
$string['TO'] = 'Tonga';
$string['TP'] = 'Timor Oriental';
$string['TR'] = 'Turqua';
$string['TT'] = 'Trinidad y Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwn';
$string['TZ'] = 'Tanzania';
$string['UA'] = 'Ucrania';
$string['UG'] = 'Uganda';
$string['US'] = 'Estados Unidos';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VA'] = 'El Vaticano';
$string['VC'] = 'San Vincente y Las Granadinas';
$string['VE'] = 'Venezuela';
$string['VG'] = 'Islas Vrgenes (Britncas)';
$string['VI'] = 'Islas Vrgenes (Americanas)';
$string['VN'] = 'Vietnam';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Gales';
$string['WF'] = 'Islas Wallis y Futuna';
$string['WS'] = 'Samoa';
$string['YE'] = 'Yemen';
$string['YT'] = 'Mayotte';
$string['ZA'] = 'Sudfrica';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbawe';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/es/countries.php <==
<?PHP // $Id$ 
      // countries.php - created with Moodle 1.4 alpha (2004081500)


$string['AD'] = 'Andorra';
$string['AE'] = 'Emiratos rabes Unidos';
$string['AF'] = 'Afganistn';
$string['AG'] = 'Antigua y Barbuda';
$string['AI'] = 'Anguila';
$string['AL'] = 'Albania';
$string['AM'] = 'Armenia';
$string['AN'] = 'Antillas Holandesas';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antrtida';
$string['AR'] = 'Argentina';
$string['AS'] = 'Samoa Americana';
$string['AT'] = 'Austria';
$string['AU'] = 'Australia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaiyn';
$string['BA'] = 'Bosnia y Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladesh';
$string['BE'] = 'Blgica';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgaria';
$string['BH'] = 'Bahrein';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BN'] = 'Brunei Darussalam';
$string['BO'] = 'Bolivia';
$string['BR'] = 'Brasil';
$string['BS'] = 'Bahamas';
$string['BT'] = 'Butn';
$string['BV'] = 'Islas Bouvet';
$string['BW'] = 'Botswana';
$string['BY'] = 'Bielorrusia';
$string['BZ'] = 'Belice';
$string['CA'] = 'Canad';
$string['CC'] = 'Islas Cocos';
$string['CF'] = 'Repblica Centroafricana';
$string['CG'] = 'Congo';
$string['CH'] = 'Suiza';
$string['CI'] = 'Costa de Marfil';
$string['CK'] = 'Islas Cook';
$string['CL'] = 'Chile';
$string['CM'] = 'Camern';
$string['CN'] = 'China';
$string['CO'] = 'Colombia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Serbia y Montenegro';
$string['CU'] = 'Cuba';
$string['CV'] = 'Cabo Verde';
$string['CX'] = 'Islas de Navidad';
$string['CY'] = 'Chipre';
$string['CZ'] = 'Repblica Checa';
$string['DE'] = 'Alemania';
$string['DJ'] = 'Djibouti';
$string['DK'] = 'Dinamarca';
$string['DM'] = 'Dominica';
$string['DO'] = 'Repblica Dominicana';
$string['DZ'] = 'Argelia';
$string['EC'] = 'Ecuador';
$string['EE'] = 'Estonia';
$string['EG'] = 'Egipto';
$string['EH'] = 'Sahara Occidental';
$string['ER'] = 'Eritrea';
$string['ES'] = 'Espaa';
$string['ET'] = 'Etiopa';
$string['FI'] = 'Finlandia';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Islas Malvinas';
$string['FM'] = 'Micronesia';
$string['FO'] = 'Islas Faroe';
$string['FR'] = 'Francia';
$string['FX'] = 'Francia Metropolitana';
$string['GA'] = 'Gabn';
$string['GB'] = 'Reino Unido';
$string['GD'] = 'Granada';
$string['GE'] = 'Georgia';
$string['GF'] = 'Guyana Francesa';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Groenlandia';
$string['GM'] = 'Gambia';
$string['GN'] = 'Guinea';
$string['GP'] = 'Guadalupe';
$string['GQ'] = 'Guinea Ecuatorial';
$string['GR'] = 'Grecia';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guyana';
$string['HK'] = 'Hong Kong';
$string['HM'] = 'Islas Heard y McDonald';
$string['HN'] = 'Honduras';
$string['HR'] = 'Croacia';
$string['HT'] = 'Hait';
$string['HU'] = 'Hungra';
$string['ID'] = 'Indonesia';
$string['IE'] = 'Irlanda';
$string['IL'] = 'Israel';
$string['IN'] = 'India';
$string['IO'] = 'Territorio Britnico del Ocano ndico';
$string['IQ'] = 'Irak';
$string['IR'] = 'Irn';
$string['IS'] = 'Islandia';
$string['IT'] = 'Italia';
$string['JM'] = 'Jamaica';
$string['JO'] = 'Jordania';
$string['JP'] = 'Japn';
$string['KE'] = 'Kenia';
$string['KG'] = 'Kirguistn';
$string['KH'] = 'Camboya';
$string['KI'] = 'Kiribati';
$string['KM'] = 'Comoras';
$string['KN'] = 'San Cristbal Nevis';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Corea del Norte';
$string['KR'] = 'Corea del Sur';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Islas Caimn';
$string['KZ'] = 'Kazajstn';
$string['LA'] = 'Laos';
$string['LB'] = 'Lbano';
$string['LC'] = 'Santa Luca';
$string['LI'] = 'Liechtenstein';
$string['LK'] = 'Sri Lanka';
$string['LR'] = 'Liberia';
$string['LS'] = 'Lesotho';
$string['LT'] = 'Lituania';
$string['LU'] = 'Luxemburgo';
$string['LV'] = 'Latvia';
$string['LY'] = 'Jamahiriya rabe Libia';
$string['MA'] = 'Marruecos';
$string['MC'] = 'Mnaco';
$string['MD'] = 'Moldovia';
$string['MG'] = 'Madagascar';
$string['MH'] = 'Islas Marshall';
$string['MK'] = 'Macedonia';
$string['ML'] = 'Mali';
$string['MM'] = 'Myanmar';
$string['MN'] = 'Mongolia';
$string['MO'] = 'Macao';
$string['MP'] = 'Islas Marianas del Norte';
$string['MQ'] = 'Martinica';
$string['MR'] = 'Mauritania';
$string['MS'] = 'Montserrat';
$string['MT'] = 'Malta';
$string['MU'] = 'Mauricio';
$string['MV'] = 'Maldivas';
$string['MW'] = 'Malawi';
$string['MX'] = 'Mxico';
$string['MY'] = 'Malasia';
$string['MZ'] = 'Mozambique';
$string['NA'] = 'Namibia';
$string['NC'] = 'Nueva Caledonia';
$string['NE'] = 'Nger';
$string['NF'] = 'Islas Norfolk';
$string['NG'] = 'Nigeria';
$string['NI'] = 'Nicaragua';
$string['NL'] = 'Holanda';
$string['NO'] = 'Noruega';
$string['NP'] = 'Nepal';
$string['NR'] = 'Naur';
$string['NU'] = 'Niue';
$string['NZ'] = 'Nueva Zelandia';
$string['OM'] = 'Omn';
$string['PA'] = 'Panam';
$string['PE'] = 'Per';
$string['PF'] = 'Polinesia Francesa';
$string['PG'] = 'Papa Nueva Guinea';
$string['PH'] = 'Filipinas';
$string['PK'] = 'Pakistn';
$string['PL'] = 'Polonia';
$string['PM'] = 'San Pedro y Miquelon';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Puerto Rico';
$string['PS'] = 'Palestina';
$string['PT'] = 'Portugal';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguay';
$string['QA'] = 'Qatar';
$string['RE'] = 'Reunin';
$string['RO'] = 'Rumania';
$string['RU'] = 'Federacin Rusa';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Arabia Saudita';
$string['SB'] = 'Islas Salomn';
$string['SC'] = 'Seychelles';
$string['SD'] = 'Sudn';
$string['SE'] = 'Suecia';
$string['SG'] = 'Singapur';
$string['SH'] = 'Santa Helena';
$string['SI'] = 'Eslovenia';
$string['SJ'] = 'Islas Svalbard y Jan Mayen';
$string['SK'] = 'Eslovaquia';
$string['SL'] = 'Sierra Leona';
$string['SM'] = 'San Marino';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somala';
$string['SR'] = 'Surinam';
$string['ST'] = 'Santo Tom y Prncipe';
$string['SV'] = 'El Salvador';
$string['SY'] = 'Siria';
$string['SZ'] = 'Swazilandia';
$string['TC'] = 'Islas Turcas y Caicos';
$string['TD'] = 'Chad';
$string['TF'] = 'Territorios Franceses del Sur';
$string['TG'] = 'Togo';
$string['TH'] = 'Tailandia';
$string['TJ'] = 'Tayikistn';
$string['TK'] = 'Tokelau';
$string['TM'] = 'Turkmenistn';
$string['TN'] = 'Tnez';
$string['TO'] = 'Tonga';
$string['TP'] = 'Timor Oriental';
$string['TR'] = 'Turqua';
$string['TT'] = 'Trinidad y Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwn';
$string['TZ'] = 'Tanzania';
$string['UA'] = 'Ucrania';
$string['UG'] = 'Uganda';
$string['US'] = 'Estados Unidos';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VA'] = 'El Vaticano';
$string['VC'] = 'San Vincente y Las Granadinas';
$string['VE'] = 'Venezuela';
$string['VG'] = 'Islas Vrgenes (Britncas)';
$string['VI'] = 'Islas Vrgenes (Americanas)';
$string['VN'] = 'Vietnam';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Gales';
$string['WF'] = 'Islas Wallis y Futuna';
$string['WS'] = 'Samoa';
$string['YE'] = 'Yemen';
$string['YT'] = 'Mayotte';
$string['ZA'] = 'Sudfrica';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbawe';

?>
